@@ -35,6 +35,19 @@ from oslo_service import _options
 from oslo_service import service
 from oslo_service import sslutils
 
+from debtcollector import removals
+
+removals.removed_module(
+    __name__,
+    replacement="uwsgi",
+    removal_version="2026.2",
+    message=(
+        "The 'oslo_service.wsgi' module is deprecated and will be removed in "
+        "version 2026.2. We recommend transitioning to 'uwsgi' for serving "
+        "WSGI applications."
+    )
+)
+
 
 LOG = logging.getLogger(__name__)
 
@@ -139,7 +152,7 @@ class Server(service.ServiceBase):
 
         try:
             sock = eventlet.listen(bind_addr, family, backlog=backlog)
-        except EnvironmentError:
+        except OSError:
             LOG.error("Could not bind to %(host)s:%(port)s",
                       {'host': host, 'port': port})
             raise
@@ -180,7 +193,7 @@ class Server(service.ServiceBase):
             'custom_pool': self._pool,
             'log': self._logger,
             'log_format': self.conf.wsgi_log_format,
-            'debug': False,
+            'debug': self.conf.wsgi_server_debug,
             'keepalive': self.conf.wsgi_keep_alive,
             'socket_timeout': self.client_socket_timeout
             }
@@ -245,7 +258,7 @@ class Request(webob.Request):
     pass
 
 
-class Router(object):
+class Router:
     """WSGI middleware that maps incoming requests to WSGI apps."""
 
     def __init__(self, mapper):
@@ -305,17 +318,17 @@ class Router(object):
 class ConfigNotFound(Exception):
     def __init__(self, path):
         msg = _('Could not find config at %(path)s') % {'path': path}
-        super(ConfigNotFound, self).__init__(msg)
+        super().__init__(msg)
 
 
 class PasteAppNotFound(Exception):
     def __init__(self, name, path):
         msg = (_("Could not load paste app '%(name)s' from %(path)s") %
                {'name': name, 'path': path})
-        super(PasteAppNotFound, self).__init__(msg)
+        super().__init__(msg)
 
 
-class Loader(object):
+class Loader:
     """Used to load WSGI applications from paste configurations."""
 
     def __init__(self, conf):
